Module ast

Module ast 

Structs

AggregateExpr
Grammar:
BinModifier
Binary Expr Modifier
BinaryExpr
Grammar:
Call
Call represents Prometheus Function. Some functions have special cases:
EvalStmt
EvalStmt holds an expression and information on the range it should be evaluated on.
Extension
Node for extending the AST. Extension won’t be generate by this parser itself.
MatrixSelector
NumberLiteral
ParenExpr
StringLiteral
SubqueryExpr
Grammar:
UnaryExpr
UnaryExpr will negate the expr
VectorMatchFillValues
VectorMatchFillValues contains the fill values to use for Vector matching when one side does not find a match on the other side. When a fill value is nil, no fill is applied for that side, and there is no output for the match group if there is no match.
VectorSelector

Enums

AtModifier
Expr
LabelModifier
LabelModifier acts as
Offset
VectorMatchCardinality
The label list provided with the group_left or group_right modifier contains additional labels from the “one”-side to be included in the result metrics.

Traits

ExtensionExpr
The interface for extending the AST with custom expression node.