pub struct VectorMatchFillValues {
pub rhs: Option<f64>,
pub lhs: Option<f64>,
}Expand description
VectorMatchFillValues contains the fill values to use for Vector matching when one side does not find a match on the other side. When a fill value is nil, no fill is applied for that side, and there is no output for the match group if there is no match.
Fields
rhs: Option<f64>lhs: Option<f64>Implementations